/**
 * Transmiter loads data from 'data' input at posedge from 'start'
 * and start their transmission after 'start' is falled down.
 * Current transmitted bit is sended through 'out'. When module
 * is ready to load new data, 'ready' is held in log. 1.
 */
module transmiter(
    input   wire        clock,
    input   wire        start,
    input   wire[7:0]   data,
    
    output  reg         ready,
    output  reg         out
);
    
    parameter start_bit = 1'b0;
    parameter stop_bit  = 1'b1;

    reg [9:0] _data;
    reg [3:0] _to_transmit;
    
    always @(posedge clock, posedge start)
    begin
        if (start)
        begin
            if (ready)
            begin
                out     <= 1;
                ready   <= 0;
                
                _to_transmit    <= 10;
                _data           <= (stop_bit << 9) | (data << 1) | start_bit; 
            end
        end
        else if (_to_transmit > 0)
        begin
            out <= _data[0];
            
            _to_transmit    <= _to_transmit - 1;
            _data           <= _data >> 1;
        end
        else
        begin
            out     <= 1;
            ready   <= 1;
        end
    end 
    
endmodule
